@@ -1,6 +1,6 @@
 use Stenciller::Standard;
 
-# VERSION
+our $VERSION = '0.1202'; # VERSION:
 # ABSTRACT: A plugin that transforms to html
 # PODNAME: Stenciller::Plugin::ToHtmlPreBlock
 
@@ -50,15 +50,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
-=head1 NAME
-
-Stenciller::Plugin::ToHtmlPreBlock - A plugin that transforms to html
-
-=head1 VERSION
-
-Version 0.1201, released 2015-01-18.
+:splint classname Stenciller::Plugin::ToHtmlPreBlock
 
 =head1 SYNOPSIS
 
@@ -70,25 +62,5 @@ Version 0.1201, released 2015-01-18.
 
 This plugin to L<Stenciller> places the C<before_input>, C<between> and C<after_output> regions in C<E<lt>pE<gt>> tags and the C<input> and C<output> regions inside C<E<lt>preE<gt>> tags.
 
-
-
-=head1 SOURCE
-
-L<https://github.com/Csson/p5-Stenciller>
-
-=head1 HOMEPAGE
-
-L<https://metacpan.org/release/Stenciller>
-
-=head1 AUTHOR
-
-Erik Carlsson <info@code301.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
+
